plugins.debate package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   plugins.debate.rooms

Submodules
----------

plugins.debate.layout module
----------------------------

.. automodule:: plugins.debate.layout
   :members:
   :undoc-members:
   :show-inheritance:

plugins.debate.overwrites module
--------------------------------

.. automodule:: plugins.debate.overwrites
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: plugins.debate
   :members:
   :undoc-members:
   :show-inheritance:
